#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.2.0.1
id: pandoc-crossref-0.2.0.1-3e3851b39cc7290c474d35f835552834
key: pando_87yR5rmmxUo2TQCNfckW50
license: GPL-2
maintainer: root@livid.pp.ru
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
author: Nikolay Yakimov
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.Settings Text.Pandoc.CrossRef.Util.Meta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Gap
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-crossref-0.2.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-crossref-0.2.0.1
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.2.0.1-87yR5rmmxUo2TQCNfckW50
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-accessor-0.2.2.7-37eef0083baebc1203ac5f772202c972
    data-accessor-template-0.2.1.12-acce0c59fb7d6535df0f0108b904c5a9
    data-accessor-transformers-0.2.1.7-082e9d05eabfdcb5b212785d058bd96b
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    pandoc-1.17.0.3-257df634e15a54e32a712d876ce77ba5
    pandoc-types-1.16.1-5c682c2b5cffa962280d4abd090bac44
    roman-numerals-0.5.1.5-895a0ef14eb8678de90c7da056b82bde
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
